/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Defines a mock concrete implementation of the <c>Server</c> class. It records the call to the methods.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public class MockServer : Server
    {
        /// <summary>
        /// Represents a flag indicating whether <c>StartUp()</c> is called.
        /// </summary>
        private bool started = false;

        /// <summary>
        /// Represents a flag indicating whether <c>ShutDown()</c> is called.
        /// </summary>
        private bool stopped = false;

        /// <summary>
        /// Represents a flag indicating whether <c>InitData()</c> is called.
        /// </summary>
        private bool initialized = false;

        /// <summary>
        /// Represents a flag indicating whether <c>CleanUpData()</c> is called.
        /// </summary>
        private bool cleaned = false;

        /// <summary>
        /// Gets the flag indicating whether <c>StartUp()</c> is called.
        /// </summary>
        /// <value><c>true</c> if <c>StartUp()</c> is called; <c>false</c> otherwise.</value>
        public bool Started
        {
            get
            {
                return started;
            }
        }

        /// <summary>
        /// Gets the flag indicating whether <c>ShutDown()</c> is called.
        /// </summary>
        /// <value><c>true</c> if <c>ShutDown()</c> is called; <c>false</c> otherwise.</value>
        public bool Stopped
        {
            get
            {
                return stopped;
            }
        }

        /// <summary>
        /// Gets the flag indicating whether <c>InitData()</c> is called.
        /// </summary>
        /// <value><c>true</c> if <c>InitData()</c> is called; <c>false</c> otherwise.</value>
        public bool Initialized
        {
            get
            {
                return initialized;
            }
        }

        /// <summary>
        /// Gets the flag indicating whether <c>CleanUpData()</c> is called.
        /// </summary>
        /// <value><c>true</c> if <c>CleanUpData()</c> is called; <c>false</c> otherwise.</value>
        public bool Cleaned
        {
            get
            {
                return cleaned;
            }
        }

        /// <summary>
        /// Creates a new instance of <c>MockServer</c> class.
        /// </summary>
        public MockServer()
        {
        }

        /// <summary>
        /// Starts up the server.
        /// </summary>
        /// <remarks>
        /// This method is called only if the start flag is set to <c>true</c>. It is called before the initialization
        /// of the server and the tests.
        /// </remarks>
        public override void StartUp()
        {
            started = true;
        }

        /// <summary>
        /// Shuts down the server.
        /// </summary>
        /// <remarks>
        /// This method is called only if the start flag is set to <c>true</c>. It is called after the deinitialization
        /// of the server and the tests.
        /// </remarks>
        public override void ShutDown()
        {
            stopped = true;
        }

        /// <summary>
        /// Initializes the data of the server.
        /// </summary>
        /// <remarks>
        /// This method is called only if the init flag is set to <c>true</c>. It is called after starting the server
        /// and before the tests.
        /// </remarks>
        public override void InitData()
        {
            initialized = true;
        }

        /// <summary>
        /// Cleans up the data of the server.
        /// </summary>
        /// <remarks>
        /// This method is called only if the init flag is set to <c>true</c>. It is called before stopping the server
        /// and after the tests.
        /// </remarks>
        public override void CleanUpData()
        {
            cleaned = true;
        }
    }
}

